@@ -52,17 +52,14 @@ Bnormal <- function(y, priors=NULL,
     chainList[[ch]] <- mcmc(chain[(burnin+1):n.iter, ])
   }
   MCMC <- mcmc.list(chainList)
-  Rhat <- try(gelman.diag(MCMC, autoburnin=FALSE)$psrf[, 1], silent=TRUE)
-  if(inherits(Rhat, "try-error") || !all(is.finite(Rhat)))
-    Rhat <- NULL
 
   out <- as.Bwiqid(MCMC,
       header = "Model fitted in R with a Gibbs sampler",
       defaultPlot = names(MCMC)[1])
   attr(out, "call") <- match.call()
   attr(out, "n.chains") <- chains
-  attr(out, "n.eff") <- effectiveSize(MCMC)
-  attr(out, "Rhat") <- Rhat
+  attr(out, "n.eff") <- safeNeff(out)
+  attr(out, "Rhat") <- simpleRhat(out, n.chains=chains)
   attr(out, "timetaken") <- Sys.time() - startTime
   return(out)
 }
