@@ -58,6 +58,7 @@ function(y, n, ci=0.95, link=c("logit", "probit"), ...)  {
   colnames(beta.mat) <- c("est", "SE", "lowCI", "uppCI")
   rownames(beta.mat) <- c("lambda", "r")
   logLik <- NA_real_
+  npar <- NA_integer_
   varcov <- NULL
 
   if(sum(n) > 0 && sum(y) > 0 && any(y < n)) {    # If all n's are 0, no data available.
@@ -93,19 +94,18 @@ function(y, n, ci=0.95, link=c("logit", "probit"), ...)  {
     nlmArgs$p <- params
     nlmArgs$hessian <- TRUE
     res <- do.call(nlm, nlmArgs)
-    # res <- nlm(nll, params, hessian=TRUE)
     if(res$code > 2)   # exit code 1 or 2 is ok.
       warning(paste("Convergence may not have been reached (code", res$code, ")"))
     beta.mat[,1] <- res$estimate
-    # varcov0 <- try(solve(res$hessian), silent=TRUE)
+    logLik <- -res$minimum
+
     varcov0 <- try(chol2inv(chol(res$hessian)), silent=TRUE)
-    # if (!inherits(varcov0, "try-error") && all(diag(varcov0) > 0)) {
     if (!inherits(varcov0, "try-error")) {
+      npar <- 2L
       varcov <- varcov0
       SE <- suppressWarnings(sqrt(diag(varcov)))
       beta.mat[, 2] <- SE
       beta.mat[, 3:4] <- sweep(outer(SE, crit), 1, res$estimate, "+")
-      logLik <- -res$minimum
     }
   }
 	lambda <- exp(beta.mat[1, -2])
@@ -117,7 +117,7 @@ function(y, n, ci=0.95, link=c("logit", "probit"), ...)  {
               beta = beta.mat,
               beta.vcv = varcov,
               real = real,
-              logLik = c(logLik=logLik, df=2, nobs=length(y)),
+              logLik = c(logLik=logLik, df=npar, nobs=length(y)),
               ci = ci,
               formulae = list(lambda = ~ 1, r = ~ 1),
               index = list(lambda = 1, r = 2))
