@@ -5,7 +5,7 @@
 
 # Check detection histories
 # -------------------------
-verifyDH <- function(DH, allowNA=FALSE) {
+verifyDH <- function(DH, allowNA=FALSE, allowNArow=FALSE) {
   if (!is.matrix(DH) && !is.data.frame(DH))
     stop("Detection history must be a matrix or data frame")
   DH <- as.matrix(DH)
@@ -15,6 +15,9 @@ verifyDH <- function(DH, allowNA=FALSE) {
     stop("Detection history has NA values.")
   if(!any(is.finite(DH)))
     stop("Detection history has no non-missing values.")
+  n <- rowSums(!is.na(DH))
+  if(!allowNArow && any(n == 0))
+    stop("Detection history has a row with all NAs.")  # added 2017-10-17
   DH <- round(DH)
   range <- range(DH, na.rm=TRUE)
   if(range[1] < 0)
